==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/hu.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Csapatok",
    "You created the team {circle}" : "Létrehozta a(z) {circle} csapatot",
    "{author} created the team {circle}" : "{author} létrehozta a(z) {circle} csapatot",
    "You deleted {circle}" : "Törölte ezt: {circle}",
    "{author} deleted {circle}" : "{author} törölte a(z) {circle} csapatot",
    "You made {member} join {circle}" : "Hozzáadta {member} tagot a(z) {circle} csapathoz",
    "{author} made {member} join {circle}" : "{author} hozzáadta {member} tagot a(z) {circle} csapathoz",
    "You added team {member} as member to {circle}" : "Tagként hozzáadta {member} felhasználót a(z) {circle} csapathoz",
    "{author} added team {member} as member to {circle}" : "{author} tagként hozzáadta {member} felhasználót a(z) {circle} csapathoz",
    "You made {member} leave {circle}" : "Eltávolította {member} tagot a(z) {circle} csapatból",
    "{author} made {member} leave {circle}" : "{author} eltávolította {member} tagot a(z) {circle} csapatból",
    "You removed {member} from {circle}" : "Eltávolította {member} tagot a(z) {circle} csapatból",
    "{author} removed {member} from {circle}" : "{author} eltávolította {member} tagot a(z) {circle} csapatból",
    "You joined {circle}" : "Csatlakozott ehhez: {circle}",
    "{member} joined {circle}" : "{member} csatlakozott ehhez: {circle}",
    "You accepted the invitation to join {circle}" : "Elfogadta a meghívást, hogy csatlakozzon a(z) {circle} csapathoz",
    "{member} accepted the invitation to join {circle}" : "{member} elfogadta a meghívást, hogy csatlakozzon a(z) {circle} csapathoz",
    "You added {member} as member to {circle}" : "Tagként hozzáadta {member} felhasználót a(z) {circle} csapathoz",
    "You have been added as member to {circle} by {author}" : "{author} hozzáadta tagként a(z) {circle} csapathoz",
    "{member} has been added as member to {circle} by {author}" : "{author} hozzáadta {member} tagot a(z) {circle} csapathoz",
    "You added {external} to {circle}" : "Hozzáadta a következőt a(z) {circle} csapathoz: {external}",
    "{external} has been added to {circle} by {author}" : "{author} hozzáadta {external} tagot a(z) {circle} csapathoz",
    "You accepted {member}'s request to join {circle}" : "Elfogadta {member} kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "Your request to join {circle} has been accepted by {author}" : "{author} elfogadta a kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} elfogadta {member} kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "You left {circle}" : "Elhagyta a(z) {circle} csapatot",
    "{member} left {circle}" : "{member} elhagyta a(z) {circle} csapatot",
    "You declined the invitation to join {circle}" : "Visszautasította a meghívást, hogy csatlakozzon a(z) {circle} csapathoz",
    "{member} declined an invitation to join {circle}" : "{member} visszautasította a meghívást, hogy csatlakozzon a(z) {circle} csapathoz",
    "You cancelled your request to join {circle}" : "Visszavonta a kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "{member} cancelled a request to join {circle}" : "{member} visszavonta a kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "You have been removed from {circle} by {author}" : "{author} eltávolította a(z) {circle} csapatból",
    "{member} has been removed from {circle} by {author}" : "{author} eltávolította {member} tagot a(z) {circle} csapatból",
    "You removed {external} from {circle}" : "Eltávolította a következőt a(z) {circle} csapatból: {external}",
    "{external} has been removed from {circle} by {author}" : "{external} eltávolította a következőt a(z) {circle} csapatból: {external}",
    "You cancelled {member}'s invitation to join {circle}" : "Visszavonta {member} meghívását a(z) {circle} csapatba",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} visszavonta a(z) {circle} csapatba való meghívását",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} visszavonta {member} meghívását a(z) {circle} csapatba",
    "You dismissed {member}'s request to join {circle}" : "Elutasította {member} kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "Your request to join {circle} has been dismissed by {author}" : "{author} elutasította a kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} elutasította {member} kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "You invited {member} to join {circle}" : "Meghívta {member} tagot, hogy csatlakozzon a(z) {circle} csapathoz",
    "You have been invited to join {circle} by {author}" : "{author} meghívta, hogy csatlakozzon a(z) {circle} csapathoz",
    "{member} has been invited to join {circle} by {author}" : "{author} meghívta {member} tagot, hogy csatlakozzon a(z) {circle} csapathoz",
    "You changed {member}'s level in {circle} to %1$s" : "Megváltoztatta {member} szintjét a(z) {circle} csapatban erre: %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} megváltoztatta az Ön szintjét a(z) {circle} csapatban erre: %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} megváltoztatta {member} szintjét a(z) {circle} csapatban erre: %1$s",
    "You sent a request to join {circle}" : "Kérést küldött, hogy csatlakozhasson a(z) {circle} csapathoz",
    "{member} sent a request to join {circle}" : "{member} kérte, hogy csatlakozhasson a(z) {circle} csapathoz",
    "You are the new owner of {circle}" : "Ön a(z) {circle} csapat új tulajdonosa",
    "{member} is the new owner of {circle}" : "{member} a(z) {circle} csapat új tulajdonosa",
    "On events happening in a <strong>team</strong> of which you are a member" : "Olyan eseményekről, amelyek olyan <strong>csapatban</strong> zajlanak, amelynek tagja",
    "Any important event in a <strong>team</strong> you are moderating" : "Bármely fontos eseményről, amely olyan <strong>csapatban</strong> történt, melyeket moderál",
    "On global events happening in any <strong>team</strong>" : "Bármely <strong>csapatban</strong> zajló globális eseményekről",
    "Single" : "Egyéni",
    "Personal" : "Személyes",
    "System" : "Rendszer",
    "Visible" : "Látható",
    "Open" : "Nyílt",
    "Invite" : "Meghívás",
    "Join request" : "Csatlakozási kérés",
    "Friends" : "Barátok",
    "Password protected" : "Jelszóval védett",
    "No Owner" : "Tulajdonos nélküli",
    "Hidden" : "Rejtett",
    "Backend" : "Háttérprogram",
    "Local" : "Helyi",
    "Root" : "Gyökér",
    "Team invite" : "Csapatmeghívás",
    "Federated" : "Föderált",
    "Mount point" : "Csatolási pont",
    "Nextcloud Account" : "Nextcloud-fiók",
    "Nextcloud Group" : "Nextcloud csoport",
    "Email address" : "E-mail-cím",
    "Contact" : "Névjegy",
    "Circle" : "Kör",
    "Nextcloud App" : "Nextcloud alkalmazás",
    "Member" : "Tag",
    "Moderator" : "Moderátor",
    "Admin" : "Rendszergazda",
    "Owner" : "Tulajdonos",
    "%s shared »%s« with you." : "%s megosztotta Önnel: »%s«.",
    "%s shared »%s« with \"%s\"." : "%s megosztotta ezt: »%s« a következővel: „%s”.",
    "%s on %s" : "%s ezen: %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s megosztotta Önnel: »%2$s«.\nMár meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s megosztotta Önnel: »%2$s«. Már meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.",
    "Password to access »%1$s« shared to you by %2$s" : "Jelszó a(z) %2$s által megosztott »%1$s« eléréséhez",
    "Password to access »%s«" : "Jelszó »%s« eléréséhez",
    "It is protected with the following password:" : "A következő jelszóval védve:",
    "%1$s via %2$s" : "%1$s-tól %2$s-ig",
    "Click the button below to open it." : "Kattintson a lenti gombra a megnyitáshoz.",
    "Open »%s«" : "»%s« megnyitása",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s több fájlt osztott meg Önnel.\nMár meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s több fájlt osztott meg Önnel. Már meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.",
    "Password to access files shared to you by %1$s" : "Jelszó a(z) %1$s által megosztott fájlok eléréséhez",
    "Password to access files" : "Jelszó a fájlok eléréséhez",
    "%s shared multiple files with \"%s\"." : "%s több fájlt osztott a következővel: „%s”.",
    "%s shared multiple files with you." : "%s több fájlt osztott meg Önnel.",
    "Boot up" : "Rendszerindítás",
    "Nextcloud Initialization" : "A Nextcloud előkészítése",
    "Circles App Initialization" : "Körök alkalmazás előkészítése",
    "Fresh installation status" : "Friss előkészítési állapot",
    "Building Local Database" : "Helyi adatbázis építése",
    "Testing Basic Circle Creation" : "Alapvető körlétrehozás tesztelése",
    "Adding local users and moderators" : "Helyi felhasználók és moderátorok hozzáadása",
    "Show all teams" : "Összes csapat megjelenítése",
    "Create a new team" : "Új csapat létrehozása",
    "Files" : "Fájlok",
    "This feature is not available for personal circles" : "Ez a szolgáltatás nem elérhető a személyes köröknél",
    "The team is not federated" : "A csapat nem föderált",
    "You cannot join this team" : "Nem csatlakozhat ehhez a csapathoz",
    "This member is not a moderator" : "Ez a tag nem moderátor",
    "Insufficient privileges" : "Elégtelen jogosultság",
    "This member does not exist" : "Ez a tag nem létezik",
    "This member is the owner of the team" : "Ez a tag a csapat tulajdonosa",
    "Level cannot be changed for this type of member" : "Az ilyen típusú tag szintje nem változtatható meg",
    "You are already a member of this circle" : "Ön már tagja ennek a körnek",
    "You have been blocked from this circle" : "Kizárták ebből a körből",
    "The account is already a member of this circle" : "A fiók már tagja e körnek",
    "The account has already been invited into this circle" : "A fiók már meg lett hívva a körbe",
    "%s (Team owned by %s)" : "%s (A csapat tulajdonosa %s)",
    "You are now a member of the Team \"%2$s\"" : "Ön most már a(z) „%2$s” csapat tagja",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s meghívta Önt a (z) „%2$s” csapatba",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s csatlakozási kérést küldött, hogy a(z) „%2$s” csapat tagja lehessen",
    "Accept" : "Elfogadás",
    "Refuse" : "Elutasítás",
    "Leave the team" : "Csapat elhagyása",
    "%s" : "%s",
    "Personal team" : "Személyes csapat",
    "%s owned by %s" : "a(z) %s tulajdonosa %s",
    "You have no permission to create a new team" : "Nincs jogosultsága új csapat létrehozásához",
    "%s shared a file with \"%s\"." : "%s megosztott egy fájlt a következővel: „%s”.",
    "%s shared a file with you." : "%s megosztott egy fájlt Önnel.",
    "Open %s" : "%s megnyitása",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s tartalmat osztott meg Önnel.\nMár meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s tartalmat osztott meg Önnel. Már meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.",
    "Password to access content shared with you by %1$s" : "Jelszó a(z) %1$s által megosztott tartalom eléréséhez",
    "Password to access content" : "Jelszó a tartalom eléréséhez",
    "This item is already shared with this team" : "Ez az elem már megosztásra került ezzel a csapattal",
    "Bring cloud-users closer together." : "Közelebb hozza a felhőfelhasználókat.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "A Csapatok lehetővé teszi, hogy az emberek létrehozzák a saját csoportjaikat a felhasználóinak/kollégáinak/barátaiknak.\nEzeket a csoportokat aztán bármely más alkalmazás használhatja megosztási célokra.",
    "No files in here" : "Itt nincsenek fájlok",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
    "Name" : "Név",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "Teams' files" : "Csapatfájlok",
    "Select team to filter by" : "Válasszon csapatot a szűréshez:",
    "No teams found" : "Nem találhatók csapatok",
    "Please select teams to filter by" : "Válasszon csapatokat a szűréshez:",
    "No files found for the selected teams" : "Nem található fájl a kiválasztott csapatokhoz",
    "Shared to Circles" : "Körökkel megosztva"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/circles/l10n/hu.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Létrehozta a(z) {circle} csapatot",
    "{author} created the team {circle}" : "{author} létrehozta a(z) {circle} csapatot",
    "You deleted {circle}" : "Törölte ezt: {circle}",
    "{author} deleted {circle}" : "{author} törölte a(z) {circle} csapatot",
    "You made {member} join {circle}" : "Hozzáadta {member} tagot a(z) {circle} csapathoz",
    "{author} made {member} join {circle}" : "{author} hozzáadta {member} tagot a(z) {circle} csapathoz",
    "You added team {member} as member to {circle}" : "Tagként hozzáadta {member} felhasználót a(z) {circle} csapathoz",
    "{author} added team {member} as member to {circle}" : "{author} tagként hozzáadta {member} felhasználót a(z) {circle} csapathoz",
    "You made {member} leave {circle}" : "Eltávolította {member} tagot a(z) {circle} csapatból",
    "{author} made {member} leave {circle}" : "{author} eltávolította {member} tagot a(z) {circle} csapatból",
    "You removed {member} from {circle}" : "Eltávolította {member} tagot a(z) {circle} csapatból",
    "{author} removed {member} from {circle}" : "{author} eltávolította {member} tagot a(z) {circle} csapatból",
    "You joined {circle}" : "Csatlakozott ehhez: {circle}",
    "{member} joined {circle}" : "{member} csatlakozott ehhez: {circle}",
    "You accepted the invitation to join {circle}" : "Elfogadta a meghívást, hogy csatlakozzon a(z) {circle} csapathoz",
    "{member} accepted the invitation to join {circle}" : "{member} elfogadta a meghívást, hogy csatlakozzon a(z) {circle} csapathoz",
    "You added {member} as member to {circle}" : "Tagként hozzáadta {member} felhasználót a(z) {circle} csapathoz",
    "You have been added as member to {circle} by {author}" : "{author} hozzáadta tagként a(z) {circle} csapathoz",
    "{member} has been added as member to {circle} by {author}" : "{author} hozzáadta {member} tagot a(z) {circle} csapathoz",
    "You added {external} to {circle}" : "Hozzáadta a következőt a(z) {circle} csapathoz: {external}",
    "{external} has been added to {circle} by {author}" : "{author} hozzáadta {external} tagot a(z) {circle} csapathoz",
    "You accepted {member}'s request to join {circle}" : "Elfogadta {member} kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "Your request to join {circle} has been accepted by {author}" : "{author} elfogadta a kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} elfogadta {member} kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "You left {circle}" : "Elhagyta a(z) {circle} csapatot",
    "{member} left {circle}" : "{member} elhagyta a(z) {circle} csapatot",
    "You declined the invitation to join {circle}" : "Visszautasította a meghívást, hogy csatlakozzon a(z) {circle} csapathoz",
    "{member} declined an invitation to join {circle}" : "{member} visszautasította a meghívást, hogy csatlakozzon a(z) {circle} csapathoz",
    "You cancelled your request to join {circle}" : "Visszavonta a kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "{member} cancelled a request to join {circle}" : "{member} visszavonta a kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "You have been removed from {circle} by {author}" : "{author} eltávolította a(z) {circle} csapatból",
    "{member} has been removed from {circle} by {author}" : "{author} eltávolította {member} tagot a(z) {circle} csapatból",
    "You removed {external} from {circle}" : "Eltávolította a következőt a(z) {circle} csapatból: {external}",
    "{external} has been removed from {circle} by {author}" : "{external} eltávolította a következőt a(z) {circle} csapatból: {external}",
    "You cancelled {member}'s invitation to join {circle}" : "Visszavonta {member} meghívását a(z) {circle} csapatba",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} visszavonta a(z) {circle} csapatba való meghívását",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} visszavonta {member} meghívását a(z) {circle} csapatba",
    "You dismissed {member}'s request to join {circle}" : "Elutasította {member} kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "Your request to join {circle} has been dismissed by {author}" : "{author} elutasította a kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} elutasította {member} kérését, hogy csatlakozzon a(z) {circle} csapathoz",
    "You invited {member} to join {circle}" : "Meghívta {member} tagot, hogy csatlakozzon a(z) {circle} csapathoz",
    "You have been invited to join {circle} by {author}" : "{author} meghívta, hogy csatlakozzon a(z) {circle} csapathoz",
    "{member} has been invited to join {circle} by {author}" : "{author} meghívta {member} tagot, hogy csatlakozzon a(z) {circle} csapathoz",
    "You changed {member}'s level in {circle} to %1$s" : "Megváltoztatta {member} szintjét a(z) {circle} csapatban erre: %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} megváltoztatta az Ön szintjét a(z) {circle} csapatban erre: %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} megváltoztatta {member} szintjét a(z) {circle} csapatban erre: %1$s",
    "You sent a request to join {circle}" : "Kérést küldött, hogy csatlakozhasson a(z) {circle} csapathoz",
    "{member} sent a request to join {circle}" : "{member} kérte, hogy csatlakozhasson a(z) {circle} csapathoz",
    "You are the new owner of {circle}" : "Ön a(z) {circle} csapat új tulajdonosa",
    "{member} is the new owner of {circle}" : "{member} a(z) {circle} csapat új tulajdonosa",
    "Teams" : "Csapatok",
    "On events happening in a <strong>team</strong> of which you are a member" : "Olyan eseményekről, amelyek olyan <strong>csapatban</strong> zajlanak, amelynek tagja",
    "Any important event in a <strong>team</strong> you are moderating" : "Bármely fontos eseményről, amely olyan <strong>csapatban</strong> történt, melyeket moderál",
    "On global events happening in any <strong>team</strong>" : "Bármely <strong>csapatban</strong> zajló globális eseményekről",
    "Single" : "Egyéni",
    "Personal" : "Személyes",
    "System" : "Rendszer",
    "Visible" : "Látható",
    "Open" : "Nyílt",
    "Invite" : "Meghívás",
    "Join request" : "Csatlakozási kérés",
    "Friends" : "Barátok",
    "Password protected" : "Jelszóval védett",
    "No Owner" : "Tulajdonos nélküli",
    "Hidden" : "Rejtett",
    "Backend" : "Háttérprogram",
    "Local" : "Helyi",
    "Root" : "Gyökér",
    "Team invite" : "Csapatmeghívás",
    "Federated" : "Föderált",
    "Mount point" : "Csatolási pont",
    "Nextcloud Account" : "Nextcloud-fiók",
    "Nextcloud Group" : "Nextcloud csoport",
    "Email address" : "E-mail-cím",
    "Contact" : "Névjegy",
    "Team" : "Csapat",
    "Nextcloud App" : "Nextcloud alkalmazás",
    "Teams App" : "Csapatok alkalmazás",
    "Admin Command Line" : "Rendszergazdai parancssor",
    "Member" : "Tag",
    "Moderator" : "Moderátor",
    "Admin" : "Rendszergazda",
    "Owner" : "Tulajdonos",
    "%s shared »%s« with you." : "%s megosztotta Önnel: »%s«.",
    "%s shared »%s« with \"%s\"." : "%s megosztotta ezt: »%s« a következővel: „%s”.",
    "%s on %s" : "%s ezen: %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s megosztotta Önnel: »%2$s«.\nMár meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s megosztotta Önnel: »%2$s«. Már meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.",
    "Password to access »%1$s« shared to you by %2$s" : "Jelszó a(z) %2$s által megosztott »%1$s« eléréséhez",
    "Password to access »%s«" : "Jelszó »%s« eléréséhez",
    "It is protected with the following password:" : "A következő jelszóval védve:",
    "%1$s via %2$s" : "%1$s-tól %2$s-ig",
    "Click the button below to open it." : "Kattintson a lenti gombra a megnyitáshoz.",
    "Open »%s«" : "»%s« megnyitása",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$s több fájlt osztott meg Önnel.\nMár meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$s több fájlt osztott meg Önnel. Már meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.",
    "Password to access files shared to you by %1$s" : "Jelszó a(z) %1$s által megosztott fájlok eléréséhez",
    "Password to access files" : "Jelszó a fájlok eléréséhez",
    "%s shared multiple files with \"%s\"." : "%s több fájlt osztott a következővel: „%s”.",
    "%s shared multiple files with you." : "%s több fájlt osztott meg Önnel.",
    "Boot up" : "Rendszerindítás",
    "Nextcloud Initialization" : "A Nextcloud előkészítése",
    "Circles App Initialization" : "Körök alkalmazás előkészítése",
    "Fresh installation status" : "Friss előkészítési állapot",
    "Building Local Database" : "Helyi adatbázis építése",
    "Adding local users and moderators" : "Helyi felhasználók és moderátorok hozzáadása",
    "Show all teams" : "Összes csapat megjelenítése",
    "Create a new team" : "Új csapat létrehozása",
    "Files" : "Fájlok",
    "The team is not federated" : "A csapat nem föderált",
    "You cannot join this team" : "Nem csatlakozhat ehhez a csapathoz",
    "This member is not a moderator" : "Ez a tag nem moderátor",
    "Insufficient privileges" : "Elégtelen jogosultság",
    "This member does not exist" : "Ez a tag nem létezik",
    "This member is the owner of the team" : "Ez a tag a csapat tulajdonosa",
    "Level cannot be changed for this type of member" : "Az ilyen típusú tag szintje nem változtatható meg",
    "%s (Team owned by %s)" : "%s (A csapat tulajdonosa %s)",
    "You are now a member of the Team \"%2$s\"" : "Ön most már a(z) „%2$s” csapat tagja",
    "You have been invited by %1$s into the Team \"%2$s\"" : "%1$s meghívta Önt a (z) „%2$s” csapatba",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s csatlakozási kérést küldött, hogy a(z) „%2$s” csapat tagja lehessen",
    "Accept" : "Elfogadás",
    "Refuse" : "Elutasítás",
    "Leave the team" : "Csapat elhagyása",
    "%s" : "%s",
    "Personal team" : "Személyes csapat",
    "%s owned by %s" : "a(z) %s tulajdonosa %s",
    "You have no permission to create a new team" : "Nincs jogosultsága új csapat létrehozásához",
    "%s shared a file with \"%s\"." : "%s megosztott egy fájlt a következővel: „%s”.",
    "%s shared a file with you." : "%s megosztott egy fájlt Önnel.",
    "%1$s shared %2$s with %3$s" : "%1$s megosztotta ezt: %2$s, vele: %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s megosztotta ezt: %2$s, vele: „%3$s”",
    "Open %s" : "%s megnyitása",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s tartalmat osztott meg Önnel.\nMár meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s tartalmat osztott meg Önnel. Már meg kellett volna kapnia a különálló e-mailt, amely a hozzáféréshez szükséges hivatkozást tartalmazza.",
    "Password to access content shared with you by %1$s" : "Jelszó a(z) %1$s által megosztott tartalom eléréséhez",
    "Password to access content" : "Jelszó a tartalom eléréséhez",
    "This item is already shared with this team" : "Ez az elem már megosztásra került ezzel a csapattal",
    "Bring cloud-users closer together." : "Közelebb hozza a felhőfelhasználókat.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "A Csapatok lehetővé teszi, hogy az emberek létrehozzák a saját csoportjaikat a felhasználóinak/kollégáinak/barátaiknak.\nEzeket a csoportokat aztán bármely más alkalmazás használhatja megosztási célokra.",
    "Failed to load teams" : "A csapatok betöltése sikertelen",
    "Try again" : "Próbálja újra",
    "No teams found" : "Nem találhatók csapatok",
    "Join or create teams to see them here." : "Csatlakozzon vagy hozzon létre csapatokat, hogy itt lássa őket.",
    "Create your first team" : "Hozza létre az első csapatát",
    "Loading…" : "Betöltés…",
    "More teams" : "Több csapat",
    "No files in here" : "Itt nincsenek fájlok",
    "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
    "Name" : "Név",
    "Size" : "Méret",
    "Modified" : "Módosítva",
    "Shared to Circles" : "Körökkel megosztva"
},
"nplurals=2; plural=(n != 1);");
